@@ -1,7 +1,7 @@
 package DefHash;
 
-our $DATE = '2019-06-18'; # DATE
-our $VERSION = '1.0.12'; # VERSION
+our $DATE = '2021-07-21'; # DATE
+our $VERSION = '1.0.13'; # VERSION
 
 1;
 # ABSTRACT: Define things according to a specification, using hashes
@@ -18,7 +18,13 @@ DefHash - Define things according to a specification, using hashes
 
 =head1 VERSION
 
-This document describes version 1.0.12 of DefHash (from Perl distribution DefHash), released on 2019-06-18.
+This document describes version 1.0.13 of DefHash (from Perl distribution DefHash), released on 2021-07-21.
+
+=head1 CONTRIBUTOR
+
+=for stopwords Steven Haryanto
+
+Steven Haryanto <sharyanto@cpan.org>
 
 =head1 HOMEPAGE
 
@@ -42,7 +48,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2019, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
